/********************************************************************16**

                         (c) COPYRIGHT 1989-2003 by 
                         Continuous Computing Corporation.
                         All rights reserved.

     This software is confidential and proprietary to Continuous Computing 
     Corporation (CCPU).  No part of this software may be reproduced,
     stored, transmitted, disclosed or used in any form or by any means
     other than as expressly provided by the written Software License 
     Agreement between CCPU and its licensee.

     CCPU warrants that for a period, as provided by the written
     Software License Agreement between CCPU and its licensee, this
     software will perform substantially to CCPU specifications as
     published at the time of shipment, exclusive of any updates or 
     upgrades, and the media used for delivery of this software will be 
     free from defects in materials and workmanship.  CCPU also warrants 
     that has the corporate authority to enter into and perform under the   
     Software License Agreement and it is the copyright owner of the software 
     as originally delivered to its licensee.

     CCPU MAKES NO OTHER WARRANTIES, EXPRESS OR IMPLIED, INCLUDING
     WITHOUT LIMITATION WARRANTIES OF MERCHANTABILITY OR FITNESS FOR
     A PARTICULAR PURPOSE WITH REGARD TO THIS SOFTWARE, SERVICE OR ANY RELATED
     MATERIALS.

     IN NO EVENT SHALL CCPU BE LIABLE FOR ANY INDIRECT, SPECIAL,
     CONSEQUENTIAL DAMAGES, OR PUNITIVE DAMAGES IN CONNECTION WITH OR ARISING
     OUT OF THE USE OF, OR INABILITY TO USE, THIS SOFTWARE, WHETHER BASED
     ON BREACH OF CONTRACT, TORT (INCLUDING NEGLIGENCE), PRODUCT
     LIABILITY, OR OTHERWISE, AND WHETHER OR NOT IT HAS BEEN ADVISED
     OF THE POSSIBILITY OF SUCH DAMAGE.

                       Restricted Rights Legend

     This software and all related materials licensed hereby are
     classified as "restricted computer software" as defined in clause
     52.227-19 of the Federal Acquisition Regulation ("FAR") and were
     developed entirely at private expense for nongovernmental purposes,
     are commercial in nature and have been regularly used for
     nongovernmental purposes, and, to the extent not published and
     copyrighted, are trade secrets and confidential and are provided
     with all rights reserved under the copyright laws of the United
     States.  The government's rights to the software and related
     materials are limited and restricted as provided in clause
     52.227-19 of the FAR.

                    IMPORTANT LIMITATION(S) ON USE

     The use of this software is limited to the use set
     forth in the written Software License Agreement between CCPU and
     its Licensee. Among other things, the use of this software
     may be limited to a particular type of Designated Equipment, as 
     defined in such Software License Agreement.
     Before any installation, use or transfer of this software, please
     consult the written Software License Agreement or contact CCPU at
     the location set forth below in order to confirm that you are
     engaging in a permissible use of the software.

                    Continuous Computing Corporation
                    9380, Carroll Park Drive
                    San Diego, CA-92121, USA

                    Tel: +1 (858) 882 8800
                    Fax: +1 (858) 777 3388

                    Email: support@trillium.com
                    Web: http://www.ccpu.com

*********************************************************************17*/


/********************************************************************20**

     Name:     Layer Manager Interface - M3UA

     Type:     C include file

     Desc:     Structures, variables and typedefs required by the
               layer manager

     File:     lit.x

     Sid:      lit.x@@/main/26 - Wed Jan 19 17:10:16 2011

     Prg:      pn

*********************************************************************21*/

#ifndef __LITX__
#define __LITX__

#ifdef __cplusplus
extern "C" {
#endif


/*
 *     The defines declared in this file correspond to defines
 *     used by the following TRILLIUM software:
 *
 *     part no.                      description
 *     --------    ----------------------------------------------
 *     1000xxx     SIGTRAN - SCTP
 *
 */

/*
 *     This software may be combined with the following TRILLIUM
 *     software:
 *
 *     part no.                      description
 *     --------    ----------------------------------------------
 *     1000xxx     SIGTRAN - Adaptation Layers
 *
 */


/* typedefs */

typedef U32 ItPsId;
typedef U16 ItPspId;
typedef U32 Trid;
typedef U32 ItNwkApp;

#ifdef LITV14
/*lit_x_001.main_20: Configuring EpList and number of endPoints for each psp*/
typedef struct _itPspEp
{
   U32       nmbEp;
   U32       endpIds[LIT_MAX_SEP];
}ItPspEp;
#endif


/* itGenCfg structure */

typedef struct _itGenCfg      /* M3UA general configuration */
{
   U8                nodeType;      /* type of M3UA - SGP or ASP */
   Bool              dpcLrnFlag;    /* DPC learning mode enable */
   U16               maxNmbNSap;    /* number of upper SAPs */
   U16               maxNmbSctSap;  /* number of lower SAPs */
   U16               maxNmbNwk;     /* number of Network Appearances */
   U16               maxNmbRtEnt;   /* number of Routing Entries */
   U16               maxNmbDpcEnt;  /* number of DPC entries */
   U16               maxNmbPs;      /* number of Peer Servers */
#if (defined(ITASP) && defined(OG_RTE_ON_LPS_STA))
   U16               maxNmbLps;     /* number of Local PS */
#endif /* ITASP && OG_RTE_ON_LPS_STA */
   U16               maxNmbPsp;     /* number of Peer Signalling Processes */
   U16               maxNmbMsg;     /* max MTP3/M3UA messages in transit */
   U16               maxNmbRndRbnLs; /* number of Round Robin Loadshare
                                         contexts */
   U16               maxNmbSlsLs;   /* number of SLS based Loadshare contexts */
 /* lit_x_001.main_24: Audit functionality added */   
#if (defined(LITV19) && defined(ITZV_AUDIT_ENABLED))
   U16		     audSctSapCbBlkSize; /* sctsapcbs in one auditreq msg */
   U16		     audAssocCbBlkSize;  /* assoccbs in one audit cycle */
   U16		     audDpcCbBlkSize;	 /* dpccbs in one audit cycle */
   U16           audPspCbBlkSize;    /* pspcbs in one audit cycle */
   U16           audPsCbBlkSize;     /* pscbs in one audit cycle */
#endif
   /* lit_x_001.main_19: Re-arranged the structure */
	Bool              drkmSupp;      /* DRKM supported */
	Bool              drstSupp;      /* DRST supported */
	S16               timeRes;       /* timer resolution */
	U32               maxNmbSls;     /* number of SLS contexts */
	U32               qSize;         /* congestion queue size in M3UA */
	U32               congLevel1;    /* congestion level 1 in the queue */
	U32               congLevel2;    /* congestion level 2 in the queue */
	U32               congLevel3;    /* congestion level 3 in the queue */
	/* lit_x_001.main_21: For Multimessage priority. */
#ifdef LITV15 
	Bool              multiMsgPrior; 
#endif  
	struct 
	{
		TmrCfg         tmrRestart;    /* restart hold-off time */
		TmrCfg         tmrMtp3Sta;    /* MTP3 status poll time */
		TmrCfg         tmrAsPend;     /* AS-PENDING time */
		TmrCfg         tmrHeartbeat;  /* heartbeat period */
		TmrCfg         tmrAspUp1;     /* initial time between ASPUP */
      TmrCfg         tmrAspUp2;     /* steady-state time between ASPUP */
      U8             nmbAspUp1;     /* initial number of ASPUP */
      TmrCfg         tmrAspDn;      /* time between ASPDN */
      TmrCfg         tmrAspM;       /* timeout value for ASPM messages */
      TmrCfg         tmrDaud;       /* time between DAUD */
      TmrCfg         tmrDrkm;       /* time between DRKM msgs */
      U8             maxNmbRkTry;       /* initial number of DRKM msgs */
      TmrCfg         tmrDunaSettle; /* time to settle DUNA message */
      TmrCfg         tmrSeqCntrl;   /* Sequence Control timer */
 /* lit_x_001.main_24: Audit functionality added */   
#if (defined(LITV19) && defined(ITZV_AUDIT_ENABLED))
      TmrCfg	     tmrAudSctSapCbBrk; /* sctsap audit break(small) timer */
      TmrCfg	     tmrAudSctSapCb;    /* sctsap audit request(long)timer */
      TmrCfg	     tmrAudAssocCbBrk; /*assocCb audit break(small) timer */
      TmrCfg	     tmrAudAssocCb;    /*assocCb audit request(long) timer */
      TmrCfg	     tmrAudDpcCbBrk; /* dpcCb audit break(small) timer */
      TmrCfg	     tmrAudDpcCb;    /* dpcCb audit request(long) timer */
      TmrCfg	     tmrAudPspCbBrk; /* pspCb audit break(small) timer */
      TmrCfg	     tmrAudPspCb;    /* pspCb audit request(long) timer */
      TmrCfg	     tmrAudPsCbBrk;  /* psCb audit break(small) timer */
      TmrCfg	     tmrAudPsCb;     /* psCb audit request(long) timer */
      /* The timers that follow are used to audit for additional control
         blocks existing at Slaves and delete the extra Cb at Slave 
         if found.
      */
      TmrCfg	     tmrAudDelSctSapCb;   /* sctsap deleted cb audit timer */
      TmrCfg	     tmrAudDelPspCb;   /*  Psp deleted cb audit timer */
      TmrCfg	     tmrAudDelPsCb;    /*  Ps deleted cb audit timer */
#endif
   } tmr;                           /* timeout values of timers */
   Pst               smPst;         /* stack manager post structure */
} ItGenCfg;

/* Network Configuration */

typedef struct itNwkCfg             /* M3UA network configuration */
{
   ItNwkApp          nwkApp[LIT_MAX_PSP]; /* network appearance code */
   /* lit_x_001.main_19: Re-arranged the structure */
   U8                nwkId;         /* network ID */
   U8                ssf;           /* sub service field */
   U8                dpcLen;        /* dpc or opc length */
   U8                slsLen;        /* sls length */
   Swtch             suSwtch;       /* protocol variant of service user */
   Swtch             su2Swtch;      /* protocol variant of user of
                                       service user */
} ItNwkCfg;

/* itNSapCfg structure */

typedef struct itNSapCfg            /* M3UA Network SAP configuration */
{
   SpId              sapId;         /* NSAP id */
   U8                nwkId;         /* logical network ID */
   U8                suType;        /* service user protocol type */
   MemoryId          mem;           /* memory region and pool id */
   /* lit_x_001.main_19: Re-arranged the structure */
   Selector          selector;      /* upper layer selector */
   Priority          prior;         /* priority */
   Route             route;         /* route */
#ifdef ITSG
   TmrCfg            tmrPrim;       /* lower SAP primitive timer */
   ProcId            procId;        /* processor ID */
   Ent               ent;           /* entity */
   Inst              inst;          /* instance */
   SpId              mtp3SapId;     /* MTP3 service provider ID */
#endif
#ifdef TDS_ROLL_UPGRADE_SUPPORT
   Bool              remIntfValid;  /* remote interface version is valid */
   CmIntfVer         remIntfVer;    /* remote interface version */
#endif /* TDS_ROLL_UPGRADE_SUPPORT */
} ItNSapCfg;



/* routing filter structure */

typedef struct _itRtFilter          /* M3UA routing filter */
{
   Dpc               dpcMask;       /* DPC wildcard mask */
   Dpc               dpc;           /* Destination Point Code */
   Dpc               opcMask;       /* OPC wildcard mask */
   Dpc               opc;           /* Originator Point Code */
   LnkSel            slsMask;       /* Link Selector wildcard mask */
   LnkSel            sls;           /* Link Selector */
   SrvInfo           sioMask;       /* SIO wildcard mask */
   SrvInfo           sio;           /* Service Identifier Octet */
   Bool              includeCic;    /* TRUE = include ISUP CIC in filter */
   Cic               cicStart;      /* Start of CIC range */
   Cic               cicEnd;        /* End of CIC range */
   Bool              includeSsn;    /* TRUE = include SCCP SSN in filter */
   Ssn               ssn;           /* Subsystem Number */
   Bool              includeTrid;   /* TRUE = include TCAP TRID in filter */
   Trid              tridStart;     /* Start of TCAP Transaction ID range */
   Trid              tridEnd;       /* End of TCAP Transaction ID range */
} ItRtFilter;

/* route entry configuration */

typedef struct _itRteCfg            /* Routing entry */
{
   U8                nwkId;         /* network ID */
   U8                rtType;        /* Route Type */
   ItRtFilter        rtFilter;      /* M3UA routing filter */
   ItPsId            psId;          /* Peer Server ID */
   Bool              nSapIdPres;    /* Upper SAP ID present */
   SpId              nSapId;        /* Upper SAP ID */
   Bool              noStatus;      /* TRUE if status suppressed */
} ItRteCfg;


/* peer server config */

typedef struct _itPsCfg             /* Peer Server configuration */
{
   ItPsId            psId;          /* Peer Server ID */
   /* lit_x_001.main_19: Re-arranged the structure */
   U32               routCtx;       /* Routing Context */
   U8                nwkId;         /* Network ID */
   U8                mode;          /* Active/Standby or load sharing */
   U8                loadShareMode; /* Round robin, SLS mapping etc. */
   Bool              reqAvail;      /* TRUE if required for SPMC availability */
   U16               nmbActPspReqd; /* number of active PSPs sharing load */
   U16               nmbPsp;        /* number of entries in PSP list */
   ItPspId           psp[LIT_MAX_PSP]; /* ordered list of PSPs */
   Bool              lclFlag;       /* PS type is local if set */
#ifdef LITV14
/*lit_x_001.main_20: Endpoint list for each psp and SLS distribution mode*/
   ItPspEp           pspEpLst[LIT_MAX_PSP];
   U8                slsDistMode;   /* SLS Distribution Mode */
#endif
/* lit_x_001.main_22: Multiple routing contexts per RK support.  */
#ifdef LITV16
   Bool              rCtxPerPspValid; /* If set to TRUE RC per each psp will be assinged. */
   U32               rCtxPerPsp[LIT_MAX_PSP];
#endif
} ItPsCfg;


/* association configuration */

typedef struct _itAssocCfg          /* SCTP association configuration */
{
   CmNetAddr         priDstAddr;    /* primary destination address */
   SctNetAddrLst     dstAddrLst;    /* destination address list */
   /* lit_x_001.main_19: Re-arranged the structure */
   U16               dstPort;       /* destination port */
   SctStrmId         locOutStrms;   /* number of streams supported */
   /* it009.106 - Added Type of Service parameter */
#ifdef SCT3
   SctTos            tos;           /* type of service */
#endif /* SCT3 */
} ItAssocCfg;

/* Peer Signalling Process configuration */

typedef struct _itPspCfg            /* Peer Signalling Process configuration */
{
   ItPspId           pspId;         /* PSP id */
   U8                pspType;       /* PSP client/server type */   
   U8                ipspMode;      /* IPSP single ended/double ended type */   
   Bool              dynRegRkallwd; /* PSP is authorized for DRKM mesg */
   U8                dfltLshareMode; /* Default mode for dynamic cfg of ps */
   Bool              nwkAppIncl;    /* Network Appearance flag */

/* lit_x_001.main_13 - ADD - Support for M3UA Release 1.7 */
#ifdef LITV10
/* RFC 4666, allows provision of sending ASP Id in ASP Up Ack. rxTxAspId
 * has been enhanced to take care of it */
   U8                rxTxAspId;      /* ASP Id send/receive flags*/
#else
   Bool              rxTxAspId;      /* ASP Id parameter */  
#endif
/* lit_x_001.main_14 - MOD - Configuring selfAspId per SEP basis */
#ifdef LITV11
   U32               selfAspId[LIT_MAX_SEP]; /* ASP Id to be sent in
                                                ASP UP message from
                                                respective SEP */
#else
   U32               selfAspId;      /* ASP Id to be sent in ASP UP message */
#endif
   ItAssocCfg        assocCfg;      /* Association configuration */
#ifdef ITASP
#ifdef SGVIEW
   U32               sgId;          /* SG Id to which this PSP belongs */
#endif /* SGVIEW */
/* lit_x_001.main_19: Re-arranged the structure */
   Bool              cfgForAllLps;  /* Configure for all local PSs? */
#endif /* ITASP */
/* lit_x_001.main_13 - ADD - Support for M3UA Release 1.7 */
#ifdef LITV10
   Bool              rcIsMand;     /*This is used only for pspType = ASP/IPSP
                                     Dictates that RC is Mandatory in the 
                                     rcvd ASP_ACTIVE message or not. */
   Bool              modRegRkallwd;  /* Re Registration is supported or not
                                      * this PSP */
#endif
/* lit_x_001.main_19: Re-arranged the structure */
   U8                nwkId;         /* Default network ID */
/* lit_x_001.main_17 - ADD - Addition of new parameter, includeRC.*/
#ifdef LITV13
   Bool              includeRC;      /*The value of this parameter controls                                            whether RC has to be included in the                                            outgoing messages where RC is optional.*/ 
#endif
#ifdef LITV14
/*lit_x_001.main_20: Added SgMated pair ID and dflt Distribution Mode*/
#if (defined(ITASP) && defined(SGVIEW))
   U32               sgMid;         /* SG Id of Sg that forms mated pair
                                     * with this SG spcified by sgId */
#endif
   U8                dfltSlsDistMode;   /* SLS Distribution Mode */
#endif
} ItPspCfg;


/* SCT SAP configuration */

typedef struct _itSctSapCfg         /* SCT SAP configuration */
{
   SuId              suId;          /* service user SAP ID */
   /* lit_x_001.main_19: Re-arranged the structure */
   U16               srcPort;       /* source port for listening endpoint */
   TmrCfg            tmrPrim;       /* lower SAP primitive time */
   TmrCfg            tmrSta;        /* congestion poll time */
   SctNetAddrLst     srcAddrLst;    /* source address list */
   MemoryId          mem;           /* memory region and pool ID */
   ProcId            procId;        /* processor ID */
   Ent               ent;           /* entity */
   Inst              inst;          /* instance */
   Priority          prior;         /* priority */
   Route             route;         /* route */
   SpId              spId;          /* service provider ID */
   /* lit_x_001.main_19: Re-arranged the structure */
   Selector          selector;      /* selector for SCT */
#ifdef TDS_ROLL_UPGRADE_SUPPORT
   Bool              remIntfValid;  /* remote interface version is valid */
   CmIntfVer         remIntfVer;    /* remote interface version */
#endif /* TDS_ROLL_UPGRADE_SUPPORT */
} ItSctSapCfg;


/* M3UA configuration structure */

typedef struct _itCfg            /* Configuration */
{
   union
   {
      ItGenCfg       genCfg;     /* M3UA General config */
      ItNwkCfg       nwkCfg;     /* M3UA Network config */
      ItNSapCfg      nSapCfg;    /* M3UA Upper SAP config */
      ItRteCfg       rteCfg;     /* M3UA addr translation table config */
      ItPsCfg        psCfg;      /* M3UA PS config */
      ItPspCfg       pspCfg;     /* M3UA PSP config */
      ItSctSapCfg    sctSapCfg;  /* M3UA Lower SAP config */
   } s;
} ItCfg;

/* it004.106 - Removed the field dpcMask as it is not being used. */
typedef struct _itCicRng {
       Dpc               opc;           /* OPC */
       Cic               cicStart;      /* Start of CIC range */
       Cic               cicEnd;        /* End of CIC range */
} ItCicRange;

typedef struct _itRoutKey         /* M3UA routing Key */
{
   Dpc               dpc;                        /* Destination Point Code */
   Dpc               opc[LIT_MAX_OPC_IN_DRKM];   /* Originator Point Code */
   /* lit_x_001.main_19: Re-arranged the structure */
   U8                nmbSio;
   U8                nmbOpc;
   U8                nmbCic;
   SrvInfo           sio[LIT_MAX_SIO_IN_DRKM];   /* Service Identifier Octet */
   ItCicRange        cicRange[LIT_MAX_CIC_IN_DRKM]; /* CIC Range */
} ItRoutKey;

/* lit_x_001.main_10: SLS DPC Mapping Table (SMT) Entry */
/*-- lit_x_001.main_15: User based load share method modification --*/
#if defined(IT_LOADSH_USR_DEFINED)

typedef struct _itLscUsrSlsDpcNwkTbl
{
   Dpc       dpc;                     /* List of DPC reachable from this PSP --*/
   Bool      dpcState;                /* DPC valid only if this is TRUE --*/
   U8        nwkId;                   /* network Id corresponding to this dpc --*/
   Bool      slsList[256];            /* list of sls for this dpc --*/
} ItLscUsrSlsDpcNwkTbl;

typedef struct _itLscUsrSlsDpcMap
{
   ItPspId                pspId;               /* PSP Identifier --*/
   Bool                   pspState;          /* Record is valid only if this is TRUE --*/
   ItLscUsrSlsDpcNwkTbl   dpcSlsNwkList[LIT_MAX_PSID];
   U32                    dpcListLen;       /* No. of DPC in the list --*/
} ItLscUsrSlsDpcMap;
#endif


/* Control */

typedef struct _itCntrl             /* Control */
{
   DateTime          dt;            /* date and time */
   Action            action;        /* action */
   Action            subAction;     /* sub action */
   union
   {
      SpId           spId;          /* SAP ID */
      SuId           suId;          /* service user SAP ID */
      ItPsId         psId;          /* PS Id */
      ItPspId        pspId;         /* PSP Id */
      U8             nwkId;         /* Network Id */
   } s;
   union
   {
      union
      {
         ProcId      dstProcId;     /* Destination ProcId */
         Route       route;         /* Destination route */
         Priority    priority;      /* Destination Priority */
         U32         parSize;       /* Dummy union size */
      } grp;
      struct
      {
         /* lit_x_001.main_19: Re-arranged the structure */
         U8          nwkId;         /* Network Id */
         U8          congLevel;     /* Congestion level */
         SuId        sctSuId;       /* SCT Sap suId */
         Dpc         dpc;           /* Destination point code */
         Dpc         conPc;         /* Concerned point code */
      } cong;
      struct
      {
         U8          nwkId;         /* Network Id */
         U8          indexType;     /* Route index type */
         union
         {
            ItPsId   psId;          /* PS ID */
            Dpc      dpc;           /* Destination point code */
            ItRteCfg rteCfg;         /* Full rteCfg */
         } u;
      } rtEnt;
      struct
      {
         SuId        sctSuId;       /* SCT Sap suId */
         Bool        autoCtx;       /* automatic routing context */
         /* lit_x_001.main_23: Fix to change the data type of nmbPs
                             to support more then 255 RC's */
#ifdef LITV17
         U16         nmbPs;         /* number of PS */
#else
         U8          nmbPs;
#endif
         ItPsId      psLst[LIT_MAX_PSID]; /* PS Id list */
         U8          info[LIT_MAX_INFO + 1]; /* INFO field */
#ifdef IT_ABORT_ASSOC
         Bool        abrtFlag;       /* abort flag */
#endif /* IT_ABORT_ASSOC */
      } aspm;
      struct
      {
         U8           reqType;        /* Request type */
         SuId        sctSuId;       /* SCT Sap suId */
         union 
         {
            struct 
            {
               U16          nmbRk;     /* Number of RKs */
               struct
               {
                  ItRoutKey   rtKey;  /* Routing Key */
                  ItPsId       psId;  /* PS ID */
                  U8           mode;  /* THM */
               } routKey[LIT_MAX_RK_IN_DRKM];
            } rK;
            struct 
            {
               U16          nmbRCtx;   /* Number of RCs */
               struct
               {
                  ItPsId       psId;  /* PS ID */
               } rteCtxLst[LIT_MAX_RC_IN_DRKM];
             } rC;
          } rkm;
      } dynRteKey;
      struct
      {
         U32         trcMask;       /* Trace Mask */
      } trc;
      struct
      {
         U16         nmbRtKey;      /* Number of RtKey */
         struct
         {
            U32         localRkId;     /* Generated Local-rk-id */
            ItRoutKey   rtKey;         /* RK to be registered */
         } rk[LIT_MAX_RK_IN_DRKM];
      } rkResp;
/* lit_x_001.main_10: SMT Info to be updated for UsrDefined Loadsharing */
#if defined(IT_LOADSH_USR_DEFINED)
      struct
      {
         ItLscUsrSlsDpcMap slsDpcTable[LIT_MAX_PSP];
         U32 slsDpcTableLen;     
      } smt; /* SMT */
#endif
#ifdef DEBUGP
      struct
      {
         U32         dbgMask;       /* Debug Mask */
      } dbg;
#endif
   } t;
} ItCntrl;

/* Solicited status */

typedef struct _itGenSta            /* General status */
{
   U32               memSize;       /* Reserved memory size */
   U32               memAlloc;      /* Allocated memory size */
} ItGenSta;

typedef struct _itNSapSta           /* Upper SAP status */
{
   SpId              lclSapId;      /* local  SAP Id */
   SpId              remSapId;      /* remote (MTP3/M3UA-User) SAP Id */
   U8                hlSt;          /* High level state */
#ifdef TDS_ROLL_UPGRADE_SUPPORT
   /* lit_x_001.main_19: Re-arranged the structure */
   Bool              remIntfValid;  /* remote interface valid ? */
   CmIntfVer         selfIntfVer;   /* self interface version */
   CmIntfVer         remIntfVer;    /* remote interface version */
#endif /* TDS_ROLL_UPGRADE_SUPPORT */
} ItNSapSta;

/* PS status per End point */
typedef struct _itPsStaEndp 
{
   U8                aspSt[LIT_MAX_PSP]; /* PS's assoc states */
   ItPspId           actPsp[LIT_MAX_PSP]; /* list of active assocs */
   /* lit_x_001.main_19: Re-arranged the structure */
   U16               nmbAct;        /* number of active assocs */
   U16               nmbPspReg;     /* number of registered assocs */
   struct
   {
      U32            rCtx;          /* routing Context */
      Bool           rcValid;       /* routing context valid flag */
      U8             mode;          /* Dynamically/Static */
   } rteCtx[LIT_MAX_PSP]; 
} ItPsStaEndp;

typedef struct _itPsSta             /* Peer Server status */
{
   ItPsId            psId;          /* Peer Server Id */
   U8                asSt;          /* PS's AS state */
   ItPsStaEndp       psStaEndp[LIT_MAX_SEP];
} ItPsSta;

typedef struct _itAssocSta          /* Association status */
{
   UConnId           spAssocId;     /* Association Id */
   U8                hlSt;          /* High level state */
   U8                aspSt;         /* PSP's ASP state */
   Bool              inhibited;     /* Management inhibit status */
   U16               nmbAct;        /* number of active PSs */
  /* lit_x_001.main_19: Re-arranged the structure */
   U16               nmbRegPs;      /* number of registered PSs */
   ItPsId            actPs[LIT_MAX_ACT_PS]; /* list of active PSs */
   ItPsId            regPs[LIT_MAX_PSID]; /* Registered PSs List */
} ItAssocSta;

typedef struct _itPspSta            /* Peer Signalling Process status */
{
   ItPspId           pspId;         /* PSP Id */
   ItAssocSta        assocSta[LIT_MAX_SEP]; /*status of PSP's all associations*/

#ifdef LITV12 
/*lit_x_001.main_16 -ADD- Added the suAssocId,pirDstAddr, dstAddrLst parameters*/
   UConnId           suAssocId[LIT_MAX_SEP];  /* 1:1 relationship between suAssocId
                                                 and assocSta*/
   CmNetAddr         priDstAddr;              /* Primary destination network address */
   SctNetAddrLst     dstAddrLst;              /* Destination network address list */
#endif /*LITV12*/
} ItPspSta;

/* lit_x_002.main_7 - Added srcAddrLst in SCT SAP status. This field is updated by the layer */
typedef struct _itSctSapSta         /* lower SAP status */
{
   SuId              suId;          /* Service user SAP Id */
   U8                hlSt;          /* High level state */
   UConnId           spEndpId;      /* SP ID of my endpoint */
   U16               nmbActAssoc;   /* Number of active associations */
#ifdef LITV4
   SctNetAddrLst     srcAddrLst;    /* source address list */
#endif /* LITV4 */
#ifdef TDS_ROLL_UPGRADE_SUPPORT
   CmIntfVer         selfIntfVer;   /* self interface version */
   Bool              remIntfValid;  /* remote interface valid ? */
   CmIntfVer         remIntfVer;    /* remote interface version */
#endif /* TDS_ROLL_UPGRADE_SUPPORT */
} ItSctSapSta;

typedef struct _itAtSta             /* Address Translation status */
{
   U16               nmbDpc;        /* Number of entries in DPC table */
   U16               nmbRout;       /* Number of entries in routing table */
} ItAtSta;

typedef struct _itRkSta             /* Dynamic Routing Key status */
{
   U16               nmbRkReg;      /* Num of RK dynamically registered */
} ItRkSta;

typedef struct _itPspRkIdSta        /* PSP's RK-Ids awaiting response */
{
   ItPspId           pspId;         /* PSP Id */
   SuId              sctSuId;       /* SCT SAP SU Id */
   U32               nmbRkReqPend;  /* nmb of RKs req pending */
   U32               lclRkId[LIT_MAX_RK_IN_DRKM]; /* RK-ids */
} ItPspRkIdSta;

typedef struct _itDpcSta            /* DPC Status */
{
   Dpc               dpc;           /* DPC value  */
   /* lit_x_001.main_19: Re-arranged the structure */
   U8                nwkId;         /* Network Id */
   U8                dpcSt;         /* DPC status */
   U8                congLevel;     /* DPC Congestion Level */ 
} ItDpcSta;


/* lit_x_001.main_11: Added structures ItDpcStaPsp, ItDpcStaAllPsp */
#ifdef LITV8
typedef struct _itDpcStaPsp
{
   U8                nwkId;
   /* lit_x_001.main_19: Re-arranged the structure */
   ItPspId           pspId;
   Dpc               dpc;
   U8                pspDpcStatus[LIT_MAX_SEP];     
}ItDpcStaPsp;

typedef struct _itDpcStaAllPsp
{
   U8                nwkId;
   U8                dpcSt;
   Dpc               dpc;
   U8                pspDpcStatus[LIT_MAX_PSP][LIT_MAX_SEP];
}ItDpcStaAllPsp;
#endif /* LITV8 */

/* lit_x_002.main_7 - Changes to optimize the size of ItSsta and psSta. */
#ifdef LITV4
/* PS status per End point */
typedef struct _itSstaPsEndp
{
   U16               nmbAct;        /* number of active assocs */
   ItPspId           actPsp[LIT_MAX_PSP]; /* list of active assocs */
   U16               nmbPspReg;     /* number of registered assocs */
   U16               nmbPsp;        /* number of entries in PSP list */
   struct
   {
      ItPspId        pspId;         /* PSP id */
      U8             aspSt;         /* PS's assoc state */
      U32            rCtx;          /* routing Context */
      Bool           rcValid;       /* routing context valid flag */
      U8             mode;          /* Dynamically/Static */
   } pspSt[LIT_MAX_PSP]; 
} ItSstaPsEndp;

typedef struct _itSstaPs            /* Peer Server status */
{
   ItPsId            psId;          /* Peer Server Id */
   U8                asSt;          /* PS's AS state */
   ItSstaPsEndp      sstaPsEndp[LIT_MAX_SEP];
} ItSstaPs;
#endif

/* lit_x_001.main_26_LPR1: Revised the itSsta structure to fix the
 * compilation error */
typedef struct _itSsta              /* Solicited status */
{
   DateTime          dt;            /* date and time */
   union
   {
      SystemId       sysId;         /* System Id */
      ItGenSta       genSta;        /* M3UA General status */
      ItNSapSta      nSapSta;       /* M3UA Upper SAP status */
      ItAtSta        atSta;         /* M3UA addr trans table status */
      ItDpcSta       dpcSta;        /* M3UA DPC Status */
      U8             nwkId;         /* M3UA Network Configuration Status */
      ItRteCfg       rteSta;        /* M3UA Route Configuration Status */
#ifdef LITV4      
      ItSstaPs       psSta;         /* M3UA PS status */
#else
      ItPsSta        psSta;         /* M3UA PS status */
#endif      
      ItPspSta       pspSta;        /* M3UA PSP status */
      ItSctSapSta    sctSapSta;     /* M3UA Lower SAP status */
      ItRkSta        rkSta;         /* Dynamic Routing key status */
      ItPspRkIdSta   pspRkIdSta;    /* Reg-req's local rk-id status */
/* lit_x_001.main_11: Added structures ItDpcStaPsp, ItDpcStaAllPsp */
#ifdef LITV8
      ItDpcStaPsp    dpcStaPsp;     /* DPC status through all EPs of PSP */
      ItDpcStaAllPsp dpcStaAllPsp;  /* DPC status through all EPs of all PSPs */
#endif /* LITV8 */
   } s;
} ItSsta;

/* Statistics */

typedef struct _itM3uaSts
{
   StsCntr           data;             /* M3UA DATA messages */
   StsCntr           duna;             /* M3UA DUNA messages */
   StsCntr           dava;             /* M3UA DAVA messages */
   StsCntr           daud;             /* M3UA DAUD messages */
   StsCntr           scon;             /* M3UA SCON messages */
   StsCntr           dupu;             /* M3UA DUPU messages */
   StsCntr           drst;             /* M3UA DRST messages */
   StsCntr           regReq;           /* M3UA REG-REQ messages */
   StsCntr           deRegReq;         /* M3UA DEREG-REQ messages */
   StsCntr           regRsp;           /* M3UA REG-RSP messages */
   StsCntr           deRegRsp;         /* M3UA DEREG-RSP messages */
   StsCntr           aspUp;            /* M3UA ASPUP messages */
   StsCntr           aspUpAck;         /* M3UA ASPUP ACK messages */
   StsCntr           aspDn;            /* M3UA ASPDN messages */
   StsCntr           aspDnAck;         /* M3UA ASPDN ACK messages */
   StsCntr           aspAc;            /* M3UA ASPAC messages */
   StsCntr           aspAcAck;         /* M3UA ASPAC ACK messages */
   StsCntr           aspIa;            /* M3UA ASPIA messages */
   StsCntr           aspIaAck;         /* M3UA ASPIA ACK messages */
   StsCntr           hBeat;            /* M3UA HBEAT messages */
   StsCntr           hBeatAck;         /* M3UA HBEAT ACK messages */
   StsCntr           err;              /* M3UA ERR messages */
   StsCntr           notify;           /* M3UA NTFY messages */
} ItM3uaSts;

typedef struct _itMtp3Sts
{
   StsCntr           data;             /* MTP3 Data primitives */
   StsCntr           pause;            /* MTP3 Pause status primitives */
   StsCntr           resume;           /* MTP3 Resume status primitives */
   StsCntr           cong;             /* MTP3 Cong status primitives */
   StsCntr           drst;             /* MTP3 Restrict status primitive */    
   StsCntr           rstBeg;           /* MTP3 Reset begin status primitives */
   StsCntr           rstEnd;           /* MTP3 Reset end status primitives */
   StsCntr           upu;              /* MTP3 UPU status primitives */
} ItMtp3Sts;

typedef struct _itDataSts
{
   StsCntr           nPdus;            /* Number of PDUs */
   StsCntr           pduBytes;         /* Total size of PDUs */
} ItDataSts;

typedef struct _itDataErrSts
{
   StsCntr           dropNoRoute;      /* Data dropped, no route found */
   StsCntr           dropPcUnavail;    /* Data dropped, point code unavail */
   StsCntr           dropPcCong;       /* Data dropped, point code congested */
   StsCntr           dropNoPspAvail;   /* Data dropped, no PSP avail */
   StsCntr           dropNoNSapAvail;  /* Data dropped, no NSAP avail */
   StsCntr           dropLoadShFail;   /* Data dropped, load-sharing failed */
   StsCntr           dropMmhFail;      /* Data dropped, M3UA message failed */
   StsCntr           dataQCong;        /* Data queued in congestion queue */
   StsCntr           dataQAsPend;      /* Data queued in AS-PENDING queue */
} ItDataErrSts;

/* lit_x_001.main_24: Audit related Statistics */   
#if (defined(LITV19) && defined(ITZV_AUDIT_ENABLED))
typedef struct _itAudSts
{
   StsCntr           sctSapAudCycle;     /* sctsap completed audit cycles */
   StsCntr           assocAudCycle;      /* assoccb completed audit cycles */
   StsCntr           dpcAudCycle;        /* dpccb completed audit cycles */
   StsCntr           pspAudCycle;        /* pspcb completed audit cycles */
   StsCntr           psAudCycle;         /* pscb completed audit cycles */
   StsCntr           sctSapAudNack;      /* NAcks for SctSap */
   StsCntr           assocAudNack;       /* NAcks for Assoc */
   StsCntr           dpcAudNack;         /* NAcks for Dpc */
   StsCntr           pspAudNack;         /* NAcks for psp */
   StsCntr           psAudNack;          /* NAcks for ps */
   StsCntr           seqAudNack;          /* NAcks for ps */
   Ticks             sctSapAudStartTime; /* sctsap audit start time */          
   Ticks             sctSapAudEndTime;   /* sctsap audit start time */          
   Ticks             assocAudStartTime;  /* assoc audit start time*/
   Ticks             assocAudEndTime;    /* assoc audit end time*/
   Ticks             dpcAudStartTime;    /* dpc audit start time*/
   Ticks             dpcAudEndTime;      /* dpc audit end time*/
   Ticks             pspAudStartTime;    /* psp audit start time*/
   Ticks             pspAudEndTime;      /* psp audit end time*/
   Ticks             psAudStartTime;     /* ps audit start time*/
   Ticks             psAudEndTime;       /* ps audit end time*/
} ItAudSts;
#endif
/* lit_x_001.main_7 - Added new statistics for association unavailability 
 * and congestion. */
/* lit_x_003.main_7 - Define ItUnavSts when LITV3 or LITV6 is defined */
#if (defined(LITV3) || defined(LITV6))
typedef struct _itUnavSts    
{
   StsCntr           unav;             /* Association unavailable */
   Ticks             durUnav;          /* Duration of association 
                                        * unavailability */
} ItUnavSts;
#endif /* LITV3 || LITV6 */

#ifdef LITV3
typedef struct _itCongSts    
{
   StsCntr           cong;             /* Association congested */
   StsCntr           cong1;            /* Association at congestion level 1 */
   StsCntr           cong2;            /* Association at congestion level 2 */
   StsCntr           cong3;            /* Association at congestion level 3 */
   Ticks             durCong;          /* Duration of association congestion */
} ItCongSts;
#endif /* LITV3 */

typedef struct _itGenSts            /* General statistics */
{
   DateTime          dt;            /* Date and time when statistics counters
                                       are initialized to zero */
   ItMtp3Sts         txMtp3Sts;     /* MTP3 message statistics - TX */
   ItMtp3Sts         rxMtp3Sts;     /* MTP3 message statistics - RX */
   ItM3uaSts         txM3uaSts;     /* M3UA message statistics - TX */
   ItM3uaSts         rxM3uaSts;     /* M3UA message statistics - RX */
   ItDataSts         liTxDataSts;   /* Lower interface data statistics - TX */
   ItDataSts         liRxDataSts;   /* Lower interface data statistics - RX */
   ItDataSts         uiTxDataSts;   /* Upper interface data statistics - TX */
   ItDataSts         uiRxDataSts;   /* Upper interface data statistics - RX */
   ItDataErrSts      downDataErrSts; /* Layer data error stats - downward */
   ItDataErrSts      upDataErrSts;  /* Layer data error statistics - upward */
/* lit_x_001.main_24: Audit related Statistics */   
#if (defined(LITV19) && defined(ITZV_AUDIT_ENABLED))
   ItAudSts          zvAuditSts;    /* Peer interface audit statistics */ 
#endif
} ItGenSts;

typedef struct _itNSapSts           /* M3UA Statistics for SNTSAP */
{
   SpId              spId;          /* NSAP Id  */
   DateTime          dt;            /* date and time when statistics
                                       counters are initialized to zero */
   ItMtp3Sts         txMtp3Sts;     /* MTP3 message statistics - TX */
   ItMtp3Sts         rxMtp3Sts;     /* MTP3 message statistics - RX */
   ItDataSts         txDataSts;     /* SAP data statistics - TX */
   ItDataSts         rxDataSts;     /* SAP data statistics - RX */
   ItDataErrSts      dataErrSts;    /* SAP data error statistics - downward */
} ItNSapSts;

typedef struct _itSctSapSts         /* M3UA Statistics for SCTSAP */
{
   SuId              suId;          /* Service user SAP Id */
   DateTime          dt;            /* date and time when statistics
                                       counters are initialized to zero */
   ItDataSts         txDataSts;     /* SAP data statistics - TX */
   ItDataSts         rxDataSts;     /* SAP data statistics - RX */
} ItSctSapSts;

typedef struct _itPspSts            /* M3UA Statistics for remote PSP */
{
   ItPspId           pspId;         /* PSP ID */
   DateTime          dt;            /* date and time when statistics
                                       counters are initialized to zero */
   struct {
   ItM3uaSts         txM3uaSts;     /* M3UA message statistics - TX */
   ItM3uaSts         rxM3uaSts;     /* M3UA message statistics - RX */
   ItDataSts         txDataSts;     /* PSP data statistics - TX */
   ItDataSts         rxDataSts;     /* PSP data statistics - RX */
   ItDataErrSts      dataErrSts;    /* PSP data error statistics - upward */
   /* lit_x_001.main_7 - Added new statistics for association unavailability 
    * and congestion. */
#ifdef LITV3
   ItUnavSts         unavSts;       /* Association unavailability statistics */
   ItCongSts         congSts;       /* Association congestion statistics */
#endif /* LITV3 */
   } assocSts[LIT_MAX_SEP];
} ItPspSts;

/* lit_x_003.main_7 */
#ifdef LITV6
typedef struct _itPsSts            /* M3UA Statistics for PS */
{
   ItPsId           psId;           /* PS ID */
   DateTime         dt;            /* date and time when statistics
                                      counters are initialized to zero */
   ItM3uaSts        txM3uaSts;     /* M3UA message statistics - TX */
   ItM3uaSts        rxM3uaSts;     /* M3UA message statistics - RX */
   ItUnavSts        unavSts;       /* PS unavailability statistics */
} ItPsSts;
#endif /* LITV6 */
/*lit_x_001.main_23-ADD-M3UA Route level statistics structure*/
#ifdef LITV18
typedef struct _itRteSts
{
   Dpc              dpc;
   U8               nwkId;
   DateTime         dt;

   ItM3uaSts        txM3uaSts;
   ItM3uaSts        rxM3uaSts;
   ItDataSts        txDataSts;
   ItDataSts        rxDataSts;
} ItRteSts;
#endif /* LITV18 */


/* Statistics */

typedef struct _itSts               /* Statistics */
{
   DateTime          dt;            /* Current date and time */
   Duration          dura;          /* duration as date and time */
   union
   {
      ItGenSts       genSts;        /* M3UA general statistics */
      ItNSapSts      sntSts;        /* M3UA SNTSAP Statistics */
      ItSctSapSts    sctSts;        /* M3UA SCTSAP Statistics */
      ItPspSts       pspSts;        /* M3UA PSP statistics */
#ifdef LITV6
      ItPsSts        psSts;         /* M3UA PS statistics */
#endif /* LITV6 */
/*lit_x_001.main_23-ADD-M3UA Route level statistics structure*/
#ifdef LITV18
      ItRteSts       rteSts;         /* M3UA Route statistics */
#endif /* LITV18 */
   } u;
} ItSts;

/* M3UA Unsolicited status structure */

typedef struct _itUsta              /* Unsolicited status */
{
   CmAlarm           alarm;         /* Common Alarm Structure */
   union
   {
      SpId           spId;          /* NSAP Id */
      SuId           suId;          /* SCTSAP Id */
      ItPspId        pspId;         /* PSP Id */
      ItPsId         psId;          /* PS Id */
      U8             nwkId;         /* Network ID */
/* lit_x_001.main_12 Added Diagnostics info/Nwk Id/Routing Ctx 
   from Peer Error messages to Layer interface    */
#ifdef LITV9
      struct
      {
          ItPspId        pspId;         /* PSP Id */
          union
          {
             U32            nwkApp;         /* Network ID */
             struct
             {
                U8             numRctx;       /* Number of routing Context */
                U32            rteCtx[LIT_MAX_PSID];   /* Routing Context */
             }rteCtx;
             struct 
             {
                U8             InfoLength;    /* Length of Diagnostic Info */
                Txt            info[LIT_MAX_INFO + 1]; /* Diagnostics info */ 
             }diagInfo;
          }errIfo;
      }errEvt;
#endif
#ifdef LIT_RTE_ALARMS
#ifdef SGVIEW
      U32            sgId;          /* SG Id */
#endif /* SGVIEW */
#endif /* LIT_RTE_ALARMS */
/* lit_x_001.main_25 : Added two parameters which are used in Audit & RTE
 *                     alarms : 1) APC 2) AssocId
 */
#ifdef LITV19
      Dpc            aPc;           /* affected point code - STITAPC */
#endif
#if (defined(LITV19) || defined(IT_ASSOC_RTE_ALARM))
      U32            assocId;       /* association ID - STITASSOC */
#endif
   } s;
   union
   {
      struct
      {
         U16         msgType;       /* ASPM message type */
         SuId        sctSuId;       /* SCT Sap suId */
         U8          tmType;        /* ASPAC/ASPIA type */
         /* lit_x_001.main_19: Re-arranged the structure */
         /* lit_x_001.main_23: Fix to change the data type of nmbPs
                             to support more then 255 RC's */     
#ifdef LITV17    
         U16         nmbPs;         /* number of PS */
#else
         U8          nmbPs;        
#endif
         Txt         info[LIT_MAX_INFO + 1]; /* INFO field */
         ItPsId      psLst[LIT_MAX_PSID]; /* PS Id list */
      } aspm;                       /* ASPM parameters */
      struct
      {
         U8          stType;        /* Notify status type */
         U8          stInfo;        /* Notify status information */
         /* lit_x_001.main_19: Re-arranged the structure */
         /* lit_x_001.main_23: Fix to change the data type of nmbPs
                             to support more than 255 RC's */
#ifdef LITV17
         U16         nmbPs;         /* number of PS */
#else
         U8          nmbPs; 
#endif
         Bool        aspIdPres;     /* Flag to indicate if ASP Id is present */
         Txt         info[LIT_MAX_INFO + 1]; /* INFO field */
         ItPsId      psLst[LIT_MAX_PSID]; /* PS Id list */
         U32         aspId;
         SuId        sctSuId;       /* SCT SAP SUID */
      } ntfy;                       /* Notify parameters */
      struct
      {
         ItPspId     pspId;         /* PSP ID */
         SuId        sctSuId;       /* SCT Sap SuId */
      } psAspEvt;                   /* PS-ASP state event parameters */
      struct
      {
         Dpc         aPc;           /* affected point code */
         U8          mask;          /* affected point code mask */
         union
         {
            U8          congLevel;  /* congestion level if event PC_CONGESTED */
            U8          servInd;    /* MTP3 service indicator */
         }p;

      } dpcEvt;                     /* DPC state event parameters */
      struct
      {
         U32        rteCtx;   /* Routing Context */
         ItRoutKey  rtKey;    /* Routing Key  */
         U32        lclRkId;  /* Local RK ID */
         ItPsId     psId;     /* PS ID */
         SuId       sctSuId;  /* SCT SuId */
      } drkmEvt; 
   } t;

} ItUsta;

/* M3UA Trace structure */

typedef struct _itTrc               /* Trace */
{
   DateTime          dt;            /* date and time */
   SuId              suId;          /* SCTSAP Id */
   U16               evnt;          /* event */
   U16               len;           /* trace length */
   U32               msgType;       /* message Type */
   U8                evntParm[LIT_MAX_TRC_LEN];  /* event parameters */
} ItTrc;

/* M3UA management structure */

typedef struct _itMgmt           /* M3UA management structure */
{
   Header            hdr;        /* header */
   CmStatus          cfm;        /* Confirm */
   union
   {
      ItCfg          cfg;        /* configuration */
      ItCntrl        cntrl;      /* control */
      ItSsta         ssta;       /* solicited status */
      ItSts          sts;        /* statistics */
      ItUsta         usta;       /* unsolicited status */
      ItTrc          trc;        /* trace */
   } t;
} ItMgmt;



/* primitives from layer manager to the M3UA driver */

typedef S16 (*LitCfgReq)         ARGS((Pst *pst, ItMgmt *cfg));
typedef S16 (*LitStsReq)         ARGS((Pst *pst, Action action, ItMgmt *sts));
typedef S16 (*LitStaReq)         ARGS((Pst *pst, ItMgmt *ssta));
typedef S16 (*LitCntrlReq)       ARGS((Pst *pst, ItMgmt *cntrl));

/* primitives from M3UA to the layer manager */

typedef S16 (*LitCfgCfm)         ARGS((Pst *pst, ItMgmt *cfg));
typedef S16 (*LitStsCfm)         ARGS((Pst *pst, ItMgmt *sts));
typedef S16 (*LitStaCfm)         ARGS((Pst *pst, ItMgmt *ssta));
typedef S16 (*LitCntrlCfm)       ARGS((Pst *pst, ItMgmt *cntrl));
typedef S16 (*LitStaInd)         ARGS((Pst *pst, ItMgmt *usta));
typedef S16 (*LitTrcInd)         ARGS((Pst *pst, ItMgmt *trc));

/* lit_x_001.main_9 Moved itActvInit and itActvTsk defination from it.x to lit.x */ 
#ifdef SS_MULTIPLE_PROCS
EXTERN S16 itActvInit ARGS((ProcId proc, Ent entity, Inst inst, Region region, 
                            Reason reason, Void** xxCb));
#else
EXTERN S16 itActvInit ARGS((Ent entity, Inst inst, Region region, 
                            Reason reason));
#endif

EXTERN S16 itActvTsk ARGS((Pst *pst, Buffer *mBuf));

/* Primitives */

EXTERN S16 ItMiLitCfgReq ARGS((Pst *pst, ItMgmt *cfg));
EXTERN S16 ItMiLitCntrlReq ARGS((Pst *pst, ItMgmt *cntrl));
EXTERN S16 ItMiLitStaReq ARGS((Pst *pst, ItMgmt *sta));
EXTERN S16 ItMiLitStsReq ARGS((Pst *pst, Action action, ItMgmt *sts));
EXTERN S16 ItMiLitCfgCfm ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 ItMiLitStsCfm ARGS((Pst *pst, ItMgmt *sts));
EXTERN S16 ItMiLitCntrlCfm ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 ItMiLitStaCfm ARGS((Pst *pst, ItMgmt *sta));
EXTERN S16 ItMiLitStaInd ARGS((Pst *pst, ItMgmt *sta));
EXTERN S16 ItMiLitTrcInd ARGS((Pst *pst, ItMgmt *trc));

#ifdef IT_FTHA
EXTERN S16 ItMiShtCntrlReq ARGS((Pst *pst, ShtCntrlReqEvnt *reqInfo));
EXTERN S16 ItMiShtCntrlCfm ARGS((Pst *pst, ShtCntrlCfmEvnt *reqInfo));
#endif /* IT_FTHA */

#ifdef SM
/* primitives implemented in the layer manager for LIT */

EXTERN S16 SmMiLitCfgCfm   ARGS((Pst *pst, ItMgmt *cfg));
EXTERN S16 SmMiLitStsCfm   ARGS((Pst *pst, ItMgmt *sts));
EXTERN S16 SmMiLitStaCfm   ARGS((Pst *pst, ItMgmt *ssta));
EXTERN S16 SmMiLitCntrlCfm ARGS((Pst *pst, ItMgmt *cntrl));
EXTERN S16 SmMiLitStaInd   ARGS((Pst *pst, ItMgmt *usta));
EXTERN S16 SmMiLitTrcInd   ARGS((Pst *pst, ItMgmt *trc));

/* primitives issued by the layer manager for LIT */

EXTERN S16 SmMiLitCfgReq   ARGS((Pst *pst, ItMgmt *cfg));
EXTERN S16 SmMiLitStsReq   ARGS((Pst *pst, Action action, ItMgmt *sts));
EXTERN S16 SmMiLitStaReq   ARGS((Pst *pst, ItMgmt *ssta));
EXTERN S16 SmMiLitCntrlReq ARGS((Pst *pst, ItMgmt *cntrl));

/* stack manager activation function */
EXTERN S16 smItActvTsk       ARGS((Pst       *pst,
                                   Buffer    *mBuf));

EXTERN S16 smItActvInit      ARGS((Ent        ent,
                                   Inst       inst,
                                   Region     region,
                                   Reason     reason));


#endif /* SM */


#ifdef LCLIT
/* packing and unpacking functions for loose coupling in the layer manager */

/* packing functions */

EXTERN S16 cmPkLitCfgReq   ARGS((Pst *pst, ItMgmt *cfg));
EXTERN S16 cmPkLitCfgCfm   ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 cmPkLitStsReq   ARGS((Pst *pst, Action action, ItMgmt *sts));
EXTERN S16 cmPkLitStsCfm   ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 cmPkLitStaReq   ARGS((Pst *pst, ItMgmt *ssta));
EXTERN S16 cmPkLitStaCfm   ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 cmPkLitCntrlReq ARGS((Pst *pst, ItMgmt *cntrl));
EXTERN S16 cmPkLitCntrlCfm ARGS((Pst *pst, ItMgmt *cfm));
EXTERN S16 cmPkLitStaInd   ARGS((Pst *pst, ItMgmt *usta));
EXTERN S16 cmPkLitTrcInd   ARGS((Pst *pst, ItMgmt *trc));

/* unpacking functions */

EXTERN S16 cmUnpkLitCfgReq     ARGS((LitCfgReq func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitCfgCfm     ARGS((LitCfgCfm func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitStsReq     ARGS((LitStsReq func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitStsCfm     ARGS((LitStsCfm func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitStaReq     ARGS((LitStaReq func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitStaCfm     ARGS((LitStaCfm func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitCntrlReq   ARGS((LitCntrlReq func,
   Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitCntrlCfm   ARGS((LitCntrlCfm func,
   Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitStaInd     ARGS((LitStaInd func, Pst *pst, Buffer *mBuf));
EXTERN S16 cmUnpkLitTrcInd     ARGS((LitTrcInd func, Pst *pst, Buffer *mBuf));

#endif /* LCLIT */


#ifdef __cplusplus
}
#endif

#endif /* __LITX__ */


/********************************************************************30**

  End of file:     lit.x@@/main/26 - Wed Jan 19 17:10:16 2011
**********************************************************************31*/


/********************************************************************40**

  Notes:

**********************************************************************41*/

/********************************************************************50**

**********************************************************************51*/


/********************************************************************60**

  Revision history:

**********************************************************************61*/

/********************************************************************80**

**********************************************************************81*/

/********************************************************************90**
 
     ver       pat    init                  description
------------ -------- ---- ----------------------------------------------
/main/3      ---      mrw  1. initial release.
/main/3      ---      as   1. Updates to Release 1.2
/main/4      ---      sg   1. Routing, IPSP and Loadshare changes.
             ---      sg   2. Updates to Release 1.3
/main/5      ---      sg   1. Update to Release 1.4
/main/5    it001.104  sg   1. Added new field for DPC Mask in ItUsta
                              structure.
           it001.104  sg   2. Added a new field for Max number of Local PS in
                              ItGenCfg, for ASP/IPSP.
           it001.104  vt   3. New PSP Configuration parameter, cfgForAllLps.
/main/5    it002.104  sg   1. Added new field sgId in ItPspCfg structure.
/main/5    it018.104  vt   1. Association Abort handling
/main/5    it022.104  uv   1. New field added for sending sgId in route
                              alarms
/main/6      ---      nt   1. Update to Release 1.5
/main/7      ---      rs   1. Update to release 1.6.
/main/7    it004.106  sg   1. Removed dpcMask from ItCicRange.
/main/7    it009.106  sg   1. Added TOS parameter to ItAssocCfg.
lit_x_001.main_7       sg   1. Added new statistics for association 
                              unavailability and congestion.
lit_x_002.main_7      sg   1. Changes under compilation flag to add 
                              srcAddrLst in SCT SAP status confirm and 
                              use new ItSstaPs structure for PS status
                              confirm.
/main/2      ---      sg   1. Added PS based statistics under compilation
                              flag LITV6. 
/main/9 lit_x_001.main_9  sb  1. Moved itActvInit and itA4ctvTsk defination to 
                                 lit.x
/main/9 lit_x_001.main_10 rce 1. SLS DPC Mapping Table (SMT) DS 
                                 for UsrDefined Loadsharing moved here
lit_x_001.main_11        vp   1. Added new structures ItDpcStaPsp,ItDpcStaAllPsp
lit_x_001.main_12        sn   1. Modified USTA structure to include DIAGNOSTICS INFO
                                 ROUTING CTX,NWKAPP
lit_x_001.main_13        aj   1. Support for M3UA Release 1.7 which conforms
                                 to RFC 4666.
lit_x_001.main_14        aj   1. Configuring selfAspId for a PSP on 
                                 per SEP basis.
lit_x_001.main_15        bk   1. User based load share method modification
lit_x_001.main_16        vrs  1. Added the suAssocId,pirDstAddr, dstAddrLst parameters
                                 in pspSta structure
lit_x_001.main_17        rnt  1. Added a new parameter, includeRC, under
                                 interface flag LITV13.
lit_x_001.main_18        nuX  1. Replaced struct by union in ItSsta structure.
lit_x_001.main_19        nuX  1. Re-arranged the Structures.
lit_x_001.main_20        vg   1.  Configuring EpList and number of endPoints for each psp
                              2.  Endpoint list for each psp and SLS distribution mode
lit_x_001.main_21      krkX   1. Added new parameter multiMsgPrior in GenCfg.
lit_x_001.main_22      krkX   1. Added new parametes in PsCfg structure to
                                 support multiple Routing context for
                                 a Routing key.  
lit_x_001.main_23      sbs    1. M3UA Route level statistics structure.
                              2. Fix to change the data type of nmbPs to
                                 support more than 255 RC's and changes are
                                 protected under LITV17 compile time flag. 
lit_x_001.main_24      adi   1. Audit Functionality added.
lit_x_001.main_25      sbs   1. Added new parameters in Usta structure to 
                                support for STITASSOC and STITAPC element in indication.
*********************************************************************91*/
